@@ -8,6 +8,8 @@ from argparse import ArgumentParser, Namespace, ArgumentError
 
 from docutils import statemachine, nodes, io, utils
 from docutils.parsers import rst
+from docutils.core import ErrorString
+from docutils.utils import SafeString
 import mistune
 
 
@@ -80,7 +82,7 @@ class RestBlockLexer(mistune.BlockLexer):
 
 class RestInlineGrammar(mistune.InlineGrammar):
     image_link = re.compile(
-        r'\[!\[(?P<alt>.*?)\]\((?P<url>.*?)\).*\]\((?P<target>.*?)\)'
+        r'\[!\[(?P<alt>.*?)\]\((?P<url>.*?)\).*?\]\((?P<target>.*?)\)'
     )
     rest_role = re.compile(r':.*?:`.*?`|`[^`]+`:.*?:')
     rest_link = re.compile(r'`[^`]*?`_')
@@ -367,8 +369,6 @@ class RestRenderer(mistune.Renderer):
 
         :param html: text content of the html snippet.
         """
-        if self.options.get('escape'):
-            html = escape(html)
         return self._raw_html(html)
 
     def newline(self):
